<?php

namespace AustraliaPost\Extensions\Business\Endpoints;

use AustraliaPost\Extensions\Business\API\Wrapper\Delete_Shipment_Request;
use AustraliaPost\Extensions\Business\Helpers\Utilities;

class Delete_Shipment_Endpoint extends Abstract_Endpoint {

	/**
	 * @param $data
	 *
	 * @return array
	 */
	public function callback( $data )
	{
		if (!isset($data['shipment_id']) ) {
			$this->abort('shipment_id must be present.');
		}

		$deleteShipmentRequest = new Delete_Shipment_Request(Utilities::get_api_connector());
		$deleteShipmentRequest->setShipmentId($data['shipment_id']);
		$response = $deleteShipmentRequest->delete();
		// the endpoint returns no response on success.
		if ($response === null ) {
			$this->delete_shipment_from_order($data);
			return ['success' => true];
		}

		if ( is_array($response) && count($response) === 0 ) {
			$this->delete_shipment_from_order($data);
			return ['success' => true];
		}

		return $response;
	}

	/**
	 * @return string
	 */
	public function action()
	{
		return 'delete_shipment';
	}

	private function delete_shipment_from_order( $data )
	{
		$order = $this->get_order($data);

		$order->delete_meta_data(Create_Shipments_Endpoint::LABELS_SHIPMENTS_META_KEY);
		$order->delete_meta_data(Create_Shipments_Endpoint::LABELS_SHIPMENTS_DATE_META_KEY);
		$order->save();
	}
}
